IOBatchBuilder

Struct IOBatchBuilder 

pub struct IOBatchBuilder { /* private fields */ }
Batch builder for multiple testcases.

use hpdg::io::IOBatchBuilder;

let batch = IOBatchBuilder::new("case".to_string())
    .range(1, 3)
    .data_id_separator("_".to_string())
    .build();
assert_eq!(batch.len(), 3);

Implementations

Source

impl IOBatchBuilder

pub fn new(prefix: String) -> Self

Create a batch builder rooted at prefix.

pub fn data_ids<I: IntoIterator<Item = usize>>(self, ids: I) -> Self

Set the explicit testcase ids that should be generated.

pub fn range(self, start: usize, end_inclusive: usize) -> Self

Use an inclusive numeric range of testcase ids.

pub fn input_suffix(self, input_suffix: String) -> Self

Set the input suffix for every generated IO value.

pub fn output_suffix(self, output_suffix: String) -> Self

Set the output suffix for every generated IO value.

pub fn data_id_separator(self, separator: String) -> Self

Set the separator inserted before each testcase id.

pub fn data_id_width(self, width: Option<usize>) -> Self

Set zero-padding width for every testcase id in the batch.

pub fn build(self) -> Vec<IO>

Materialize the configured batch as a list of IO helpers.