pub trait Weight:
Copy
+ Clone
+ Default
+ Debug
+ Display
+ PartialOrd { }Expand description
Marker trait for values that can act as edge weights.
This is primarily useful when building generic generator layers on top of hpdg.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.